#include "DateTimeSettings.h"
#include <QtDebug>

const QString DateTimeSettings::weekDays[DAYS_IN_A_WEEK]=
{ 
	"Sunday", 
	"Monday", 
	"Tuesday", 
	"Wednesday", 
	"Thursday", 
	"Friday",
	"Saturday" 
};

DateTimeSettings::DateTimeSettings(const QDateTime &aStandardTimeChange, const QDateTime &aDaylightTimeChange, weekDay aDayOfWeek)
{
	this->iDaylightSaveTimeChangeMoment = aDaylightTimeChange;
	this->iStandardTimeChangeMoment = aStandardTimeChange;
	this->iDayOfWeek = aDayOfWeek;
}

DateTimeSettings::DateTimeSettings(const DateTimeSettings &aOther)
{
	this->iDaylightSaveTimeChangeMoment = aOther.iDaylightSaveTimeChangeMoment;
	this->iStandardTimeChangeMoment = aOther.iStandardTimeChangeMoment;
	this->iDayOfWeek = aOther.iDayOfWeek;
}

DateTimeSettings::~DateTimeSettings()
{

}

QDateTime DateTimeSettings::STDDateTime()
{
	return (this->iStandardTimeChangeMoment);
}

QDateTime DateTimeSettings::DSTDateTime()
{
	return (this->iDaylightSaveTimeChangeMoment);
}

QString DateTimeSettings::STDTime()
{
	QTime time = this->iStandardTimeChangeMoment.time();

	qDebug() << "DateTimeSettings::standardTimeChange_Time: "
			+time.toString("hh:mm:ss");

	return (time.toString("hh:mm:ss"));
}

QString DateTimeSettings::STDMonth()
{
	QDate date = this->iStandardTimeChangeMoment.date();

	qDebug() << "DateTimeSettings::standardTimeChange_Month: "
			+date.toString("MM");

	return (date.toString("M"));
}

QString DateTimeSettings::STDDay()
{
	QDate date = this->iStandardTimeChangeMoment.date();

	qDebug() << "DateTimeSettings::standardTimeChange_Day: "
			+date.toString("dd");

	return (date.toString("d"));
}

QString DateTimeSettings::DSTTime()
{
	QTime time = this->iDaylightSaveTimeChangeMoment.time();

	qDebug() << "DateTimeSettings::daylightSaveTimeChange_Time: "
			+time.toString("hh:mm:ss");

	return (time.toString("hh:mm:ss"));
}

QString DateTimeSettings::DSTMonth()
{
	QDate date = this->iDaylightSaveTimeChangeMoment.date();

	qDebug() << "DateTimeSettings::daylightSaveTimeChange_Month: "
			+date.toString("MM");

	return (date.toString("M"));
}

QString DateTimeSettings::DSTDay()
{
	QDate date = this->iDaylightSaveTimeChangeMoment.date();

	qDebug() << "DateTimeSettings::daylightSaveTimeChange_Day: "
			+date.toString("dd");

	return (date.toString("d"));
}

void DateTimeSettings::setDSTDateTime(const QDateTime &aDaylightSaveTimeChange)
{
	this->iDaylightSaveTimeChangeMoment = aDaylightSaveTimeChange;
	qDebug() << "DateTimeSettings::setDaylightSaveTimeChange: "
				+this->iDaylightSaveTimeChangeMoment.toString("dd.MM.yyyy hh:mm:ss");
}

void DateTimeSettings::setSTDDateTime(const QDateTime &aStandardTimeChange)
{
	this->iStandardTimeChangeMoment = aStandardTimeChange;
	qDebug() << "DateTimeSettings::setStandardTimeChange: "
					+this->iStandardTimeChangeMoment.toString("dd.MM.yyyy hh:mm:ss");
}

void DateTimeSettings::setSwitchDay(weekDay aDay)
{
	this->iDayOfWeek = aDay;
	qDebug() << "DateTimeSettings::setDayOfWeek: "
						+DateTimeSettings::weekDays[this->iDayOfWeek];
}

QString DateTimeSettings::switchDay()
{
	qDebug() << "DateTimeSettings::dayOfWeek: " +DateTimeSettings::weekDays[this->iDayOfWeek];
	return(DateTimeSettings::weekDays[this->iDayOfWeek]);
}
