#include "Meeting.h"
#include "Room.h"

Meeting::Meeting( const QString &aPrimaryId,
				  const Room &aRoom,
				  const QDateTime &aStartsAt,
				  const QDateTime &aEndsAt,
				  const QString &aSubject,
				  const QString &aOrganizerName,
				  const QString &aOrganizerEMail,
				  const QString &aDescription ) :
		iPrimaryId( aPrimaryId ),
		iSecondaryId( QString::null ),
		iRoom( aRoom ),
		iStartsAt( aStartsAt ),
		iEndsAt( aEndsAt ),
		iSubject( aSubject ),
		iOrganizerName( aOrganizerName ),
		iOrganizerEMail( aOrganizerEMail ),
		iDescription( aDescription ),
		iDetailsAvailable( false )
{
}

Meeting::~Meeting()
{
}

Room Meeting::room() const
{
	return iRoom;
}

QString Meeting::primaryId() const
{
	return iPrimaryId;
}

QString Meeting::secondaryId() const
{
	return iSecondaryId;
}

QString Meeting::organizer() const
{
	if ( iOrganizerName == "" && iOrganizerEMail != "" )
	{
		return iOrganizerEMail;
	}
	if ( iOrganizerName != "" && iOrganizerEMail == "" )
	{
		return iOrganizerName;
	}
	if ( iOrganizerEMail == "" && iOrganizerName == "" )
	{
		return "";
	}
	return QString( "%1 <%2>" ).arg( iOrganizerName ).arg( iOrganizerEMail );

}

QDateTime Meeting::startsAt() const
{
	return iStartsAt;
}

QDateTime Meeting::endsAt() const
{
	return iEndsAt;
}

QString Meeting::subject() const
{
	return iSubject;
}

QString Meeting::description() const
{
	return iDescription;
}

bool Meeting::detailsAvailable() const
{
	return iDetailsAvailable;
}

void Meeting::setSecondaryId( const QString& aSecondaryId )
{
	iSecondaryId = aSecondaryId;
	iDetailsAvailable = true;
}

void Meeting::setOrganizer( const QString &aOrganizerName, const QString &aOrganizerEMail )
{
	iOrganizerName = aOrganizerName;
	iOrganizerEMail = aOrganizerEMail;
}

void Meeting::setStartsAt( QDateTime aNewStart )
{
	iStartsAt = aNewStart;
}

void Meeting::setEndsAt( QDateTime aNewEnd )
{
	iEndsAt = aNewEnd;
}

void Meeting::setSubject( const QString &aSubject )
{
	iSubject = aSubject;
}

void Meeting::setDescription( const QString &aDescription )
{
	iDescription = aDescription;
}

bool Meeting::equals( const Meeting &aOther ) const
{
	if ( iRoom.equals( aOther.room() )
		  && iStartsAt == aOther.iStartsAt
		  && iEndsAt == aOther.iEndsAt
		  && iPrimaryId == aOther.iPrimaryId )
	{
		return true;
	}
	return false;
}

bool Meeting::overlaps( const Meeting &aOther ) const
{
	return (( iStartsAt >= aOther.iStartsAt && iStartsAt < aOther.iEndsAt ) ||
		  ( iStartsAt <= aOther.iStartsAt && iEndsAt > aOther.iStartsAt ) );
}

QString Meeting::toString() const
{
	QString meetingToString = QString( "[MEETING: id1:%1 id2:%2 in:%3 from:%4 until:%5 by:%6 subject:%7 description:%8]" )
					  .arg( iPrimaryId )
					  .arg( iSecondaryId )
					  .arg( iRoom.toString() )
					  .arg( iStartsAt.toString() )
					  .arg( iEndsAt.toString() )
					  .arg( organizer() )
					  .arg( iSubject )
					  .arg( iDescription );

	return meetingToString;
}
